@@ -10,7 +10,7 @@ class MarpaX::Languages::M4::Impl::Parser::Actions {
     use MarpaX::Languages::M4::Type::Macro -all;
     use Types::Common::Numeric -all;
 
-    our $VERSION = '0.004'; # VERSION
+    our $VERSION = '0.005'; # VERSION
 
     has macro => (
         is  => 'rw',
@@ -89,10 +89,10 @@ class MarpaX::Languages::M4::Impl::Parser::Actions {
 class MarpaX::Languages::M4::Impl::Parser {
     use MarpaX::Languages::M4::Type::Macro -all;
     use MarpaX::Languages::M4::Impl::Value;
-    use Marpa::R2; # 2.103_004;
+    use Marpa::R2;                               # 2.103_004;
     use Scalar::Util qw/readonly/;
     use Types::Common::Numeric -all;
-    use Throwable::Factory NoLexeme => undef;
+    use Throwable::Factory NoLexeme => undef, NoParseValue => undef;
 
     our $BASE_GRAMMAR = q{
 inaccessible is ok by default
@@ -255,17 +255,16 @@ COMMA ~ ',' _WS_any
 
     again:
         while ( $rc{pos} <= $maxPos ) {
+
             # $self->logger_debug( '[%d..%d/%d] 20 first characters: %s',
             #     $rc{pos}, $rc{pos}, $maxPos,
             #     substr( ${$inputRef}, $rc{pos}, 20 ) );
 
-            my %events   = map { $_->[0] => 1 } @{ $r->events };
-            my %expected = map { $_      => 1 } @{ $r->terminals_expected };
+            my %expected = map { $_ => 1 } @{ $r->terminals_expected };
 
             # $self->logger_debug(
-            #    '[%d..%d/%d] Events: %s, Expected terminals: %s',
+            #    '[%d..%d/%d] Expected terminals: %s',
             #    $rc{pos}, $rc{pos}, $maxPos,
-            #    [ keys %events ],
             #    [ keys %expected ]
             # );
 
@@ -460,9 +459,6 @@ COMMA ~ ',' _WS_any
                             $BYMACROARGUMENTS_G, $thisMacro
                         );
                         $self->_set__parse_level( $self->_parse_level - 1 );
-                        #
-                        # This will croak if dict is not defined
-                        #
 
                         # $self->logger_debug( '[%d..%d/%d] <= %s',
                         #     $rc{pos}, $rc{pos}, $maxPos, $dict );
@@ -600,7 +596,14 @@ COMMA ~ ',' _WS_any
             # is of concern for a macro that called us.
             #
             local $MarpaX::Languages::M4::Impl::Parser::macro = $macro;
-            $rc{value} = ${ $r->value };
+            my $valueRef = $r->value;
+            if ( Undef->check($valueRef) ) {
+                NoParseValue->throw(
+                    "No parse value starting at position $pos (20 first characters): "
+                        . substr( ${$inputRef}, $pos, 20 ) );
+            }
+
+            $rc{value} = ${$valueRef};
         }
         else {
             #
@@ -623,7 +626,7 @@ COMMA ~ ',' _WS_any
 
         my $rc = $self->_parseByGrammar( $inputRef, 0, $BYTOKEN_G );
         if ( !Undef->check($rc) ) {
-            return substr(${$inputRef}, $rc->{pos});
+            return substr( ${$inputRef}, $rc->{pos} );
         }
 
         return ${$inputRef};
@@ -644,6 +647,8 @@ COMMA ~ ',' _WS_any
 
 }
 
+1;
+
 __END__
 
 =pod
@@ -656,7 +661,7 @@ MarpaX::Languages::M4::Impl::Parser::Actions - M4 Macro Parser Marpa actions
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 AUTHOR
 
